# jquery.matchHeight Browser Tests

padding
margin
border
border-box
by row

## Lorem ipsum

Phasellus ut nibh fermentum, vulputate urna vel, semper diam.

Aenean semper felis ipsum, vulputate consequat dui elementum vel.

### Lorem ipsum dolor

Phasellus ut nibh fermentum, vulputate urna vel, semper diam. Nunc sollicitudin felis ut pellentesque fermentum. In erat mi, pulvinar sit amet tincidunt vitae, gravida id felis. Phasellus hendrerit erat sed porta imperdiet. Vivamus viverra ipsum tortor, et congue mauris porttitor ut.

#### Lorem ipsum dolor sit amet.

Aenean semper felis ipsum, vulputate consequat dui elementum vel. Nullam odio eros, sagittis vitae lectus id, pretium viverra lectus. Etiam auctor dolor non dui ultricies pulvinar.

### Lorem ipsum dolor

Aenean semper.

### Lorem ipsum dolor

Phasellus ut nibh fermentum, vulputate urna vel, semper diam. Nunc sollicitudin felis ut pellentesque fermentum. In erat mi, pulvinar sit amet tincidunt vitae, gravida id felis.

### Lorem ipsum dolor

Aenean semper felis ipsum, vulputate consequat dui elementum vel.

### Lorem ipsum dolor

Lorem ipsum dolor sit amet, consectetur adipiscing elit.

### Lorem ipsum dolor

Phasellus ut nibh fermentum, vulputate urna vel, semper diam.

### Lorem ipsum dolor

Phasellus ut nibh fermentum, vulputate urna vel, semper diam.

Aenean semper felis ipsum, vulputate consequat dui elementum vel.

Phasellus ut nibh fermentum, vulputate urna vel, semper diam. Nunc sollicitudin felis ut pellentesque fermentum. In erat mi, pulvinar sit amet tincidunt vitae, gravida id felis. Phasellus hendrerit erat sed porta imperdiet. Vivamus viverra ipsum tortor, et congue mauris porttitor ut.

Phasellus ut nibh fermentum, vulputate urna vel, semper diam. Nunc sollicitudin felis ut pellentesque fermentum. In erat mi, pulvinar sit amet tincidunt vitae, gravida id felis.

Aenean

Lorem

Phasellus

Aenean semper felis ipsum, vulputate consequat dui elementum vel.

Lorem ipsum dolor sit amet, consectetur adipiscing elit.

Phasellus ut nibh fermentum, vulputate urna vel, semper diam.

### data-match-height="items-a"

Phasellus ut nibh fermentum, vulputate urna vel, semper diam. Nunc sollicitudin felis ut pellentesque fermentum. In erat mi, pulvinar sit amet tincidunt vitae, gravida id felis. Phasellus hendrerit erat sed porta imperdiet. Vivamus viverra ipsum tortor, et congue mauris porttitor ut.

### data-match-height="items-a"

Phasellus ut nibh fermentum, vulputate urna vel, semper diam. Nunc sollicitudin felis ut pellentesque fermentum. In erat mi, pulvinar sit amet tincidunt vitae, gravida id felis.

### data-mh="items-b"

In erat mi, pulvinar sit amet tincidunt vitae, gravida id felis.

### data-mh="items-b"

Nunc sollicitudin felis ut pellentesque fermentum. In erat mi, pulvinar sit amet tincidunt vitae, gravida id felis.

Phasellus ut nibh fermentum, vulputate urna vel, semper diam.

Aenean semper felis ipsum, vulputate consequat dui elementum vel.

Phasellus ut nibh fermentum, vulputate urna vel, semper diam. Nunc sollicitudin felis ut pellentesque fermentum. In erat mi, pulvinar sit amet tincidunt vitae, gravida id felis. Phasellus hendrerit erat sed porta imperdiet. Vivamus viverra ipsum tortor, et congue mauris porttitor ut.

Phasellus ut nibh fermentum, vulputate urna vel, semper diam. Nunc sollicitudin felis ut pellentesque fermentum. In erat mi, pulvinar sit amet tincidunt vitae, gravida id felis.

Phasellus ut nibh fermentum, vulputate urna vel, semper diam. Nunc sollicitudin felis ut pellentesque fermentum. In erat mi, pulvinar sit amet tincidunt vitae, gravida id felis. Phasellus hendrerit erat sed porta imperdiet. Vivamus viverra ipsum tortor, et congue mauris porttitor ut.

Phasellus ut nibh fermentum, vulputate urna vel, semper diam. Nunc sollicitudin felis ut pellentesque fermentum. In erat mi, pulvinar sit amet tincidunt vitae, gravida id felis.

### Target

Phasellus ut nibh fermentum, vulputate urna vel, semper diam. Nunc sollicitudin felis ut pellentesque fermentum. In erat mi, pulvinar sit amet tincidunt vitae, gravida id felis.

Phasellus ut nibh fermentum, vulputate urna vel, semper diam. Nunc sollicitudin felis ut pellentesque fermentum. In erat mi, pulvinar sit amet tincidunt vitae, gravida id felis. Phasellus hendrerit erat sed porta imperdiet. Vivamus viverra ipsum tortor, et congue mauris porttitor ut.

Phasellus ut nibh fermentum, vulputate urna vel, semper diam. Nunc sollicitudin felis ut pellentesque fermentum. In erat mi, pulvinar sit amet tincidunt vitae, gravida id felis. Phasellus hendrerit erat sed porta imperdiet. Vivamus viverra ipsum tortor, et congue mauris porttitor ut.

Phasellus ut nibh fermentum, vulputate urna vel, semper diam. Nunc sollicitudin felis ut pellentesque fermentum. In erat mi, pulvinar sit amet tincidunt vitae, gravida id felis.

Phasellus ut nibh fermentum, vulputate urna vel, semper diam.

Aenean semper felis ipsum, vulputate consequat dui elementum vel.

Phasellus ut nibh fermentum, vulputate urna vel, semper diam. Nunc sollicitudin felis ut pellentesque fermentum. In erat mi, pulvinar sit amet tincidunt vitae, gravida id felis.

Fixed height

Fixed height

Fixed height

Fixed height

display: inline-block

display: inline-block

display: inline-block

display: inline-block

display: inline-block

display: inline-block

display: inline-block

display: inline-block

display: inline-flex

display: inline-flex

display: inline-flex

display: inline-flex

display: inline-flex

display: inline-flex

display: inline-flex

display: inline-flex

display: none

visibility: hidden

parent display: none

parent display: none

parent visibility: hidden

parent visibility: hidden

### Floating element

Phasellus ut nibh fermentum, vulputate urna vel, semper diam.

Aenean semper felis ipsum, vulputate consequat dui elementum vel.

Phasellus ut nibh fermentum, vulputate urna vel, semper diam. Nunc sollicitudin felis ut pellentesque fermentum. In erat mi, pulvinar sit amet tincidunt vitae, gravida id felis. Phasellus hendrerit erat sed porta imperdiet. Vivamus viverra ipsum tortor, et congue mauris porttitor ut.

Phasellus ut nibh fermentum, vulputate urna vel, semper diam. Nunc sollicitudin felis ut pellentesque fermentum. In erat mi, pulvinar sit amet tincidunt vitae, gravida id felis.

### Lorem ipsum dolor

Phasellus ut nibh fermentum, vulputate urna vel, semper diam. Nunc sollicitudin felis ut pellentesque fermentum. In erat mi, pulvinar sit amet tincidunt vitae, gravida id felis.

### Lorem ipsum dolor

Aenean semper felis ipsum, vulputate consequat dui elementum vel.

### Lorem ipsum dolor

Aenean semper felis ipsum, vulputate consequat dui elementum vel. Nullam odio eros, sagittis vitae lectus id, pretium viverra lectus. Etiam auctor dolor non dui ultricies pulvinar.

### Lorem ipsum dolor

Phasellus ut nibh fermentum, vulputate urna vel, semper diam.

## min-height

Phasellus ut nibh fermentum, vulputate urna vel, semper diam.

Aenean semper felis ipsum, vulputate consequat dui elementum vel.

### min-height

Phasellus ut nibh fermentum, vulputate urna vel, semper diam. Nunc sollicitudin felis ut pellentesque fermentum. In erat mi, pulvinar sit amet tincidunt vitae, gravida id felis. Phasellus hendrerit erat sed porta imperdiet. Vivamus viverra ipsum tortor, et congue mauris porttitor ut.

#### min-height

Aenean semper felis ipsum, vulputate consequat dui elementum vel. Nullam odio eros, sagittis vitae lectus id, pretium viverra lectus. Etiam auctor dolor non dui ultricies pulvinar.

### min-height

Aenean semper.

## inline style

Phasellus ut nibh fermentum, vulputate urna vel, semper diam.

Aenean semper felis ipsum, vulputate consequat dui elementum vel.

### inline style

Phasellus ut nibh fermentum, vulputate urna vel, semper diam. Nunc sollicitudin felis ut pellentesque fermentum. In erat mi, pulvinar sit amet tincidunt vitae, gravida id felis. Phasellus hendrerit erat sed porta imperdiet. Vivamus viverra ipsum tortor, et congue mauris porttitor ut.

#### inline style

Aenean semper felis ipsum, vulputate consequat dui elementum vel. Nullam odio eros, sagittis vitae lectus id, pretium viverra lectus. Etiam auctor dolor non dui ultricies pulvinar.

### inline style

Aenean semper.

## removed

Phasellus ut nibh fermentum, vulputate urna vel, semper diam.

Aenean semper felis ipsum, vulputate consequat dui elementum vel.

Phasellus ut nibh fermentum, vulputate urna vel, semper diam. Nunc sollicitudin felis ut pellentesque fermentum. In erat mi, pulvinar sit amet tincidunt vitae, gravida id felis. Phasellus hendrerit erat sed porta imperdiet. Vivamus viverra ipsum tortor, et congue mauris porttitor ut.

Aenean semper felis ipsum, vulputate consequat dui elementum vel. Nullam odio eros, sagittis vitae lectus id, pretium viverra lectus. Etiam auctor dolor non dui ultricies pulvinar.

Aenean semper.